from .detection_parse import DetectionParse
from .semantic_seg_parse import SemanticSegmentationParse
from .keypoint_parse import KeyPoint2DParse
__all__ = [
    "DetectionParse",
    "SemanticSegmentationParse",
    "KeyPoint2DParse",
]
